@@ -14,7 +14,7 @@ $lang['ask_delete_icon'] = 'Are you sure you want to remove this icon from the l
 $lang['ask_reset_icons'] = 'Are you sure you want to remove all icons, and reset to factory defaults?';
 
 # B
-$lang['baloon_maptemplate'] = 'Baloon Template';
+$lang['baloon_maptemplate'] = 'Balloon Template';
 
 # C
 $lang['cancel'] = 'Cancel';
@@ -118,7 +118,7 @@ $lang['info_sensor'] = 'Some browsers (particularly mobile browsers) are capable
 $lang['info_sidebar'] = 'Should a sidebar containing all map points be displayed?';
 $lang['info_sv_controls'] = 'Should StreetView Controls be displayed on the map?';
 $lang['info_sv_radius'] = 'When Streetview is enabled for a marker, how far (in meters) should it search for a valid streetview location.  This is important in rural areas where StreetView has not necessarily gone through every street.';
-$lang['info_sysdflt_baloon_template'] = 'System Default &quot;Baloon&quot; Template';
+$lang['info_sysdflt_baloon_template'] = 'System Default &quot;Balloon&quot; Template';
 $lang['info_sysdflt_category_template'] = 'System Default &quot;Category List&quot; Template';
 $lang['info_sysdflt_dirform_template'] = 'System Default &quot;Directions Form&quot; Template';
 $lang['info_sysdflt_js_template'] = 'System Default Javascript Template';
